@@ -645,10 +645,6 @@ class TestGameDotTree(unittest.TestCase):
         assets = GameDotTree('assets')
         assets.images.small.png.load()
         output = assets.images.small.png.info(to_stdout=False)
-        print()
-        import json
-        print(json.dumps(output, indent=4, sort_keys=True))
-        print()
         expected_output = ("{'resolution': (123, 456), 'width': 123, 'height': 456, "
                            "'pixels': 56088, 'aspect': '0.27:1', 'color_bit_depth':"
                            " 32, 'has_alpha': True, 'color_key': None, 'size': "
@@ -659,7 +655,6 @@ class TestGameDotTree(unittest.TestCase):
 
 
 
-
 if __name__ == '__main__':
 
     unittest.main()
